"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DetectorModelPayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_EXPRESSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content_expression: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content_expression: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_expression", b"content_expression", "resource_info", b"resource_info"]) -> None: ...

global___DetectorModelPayload = DetectorModelPayload

@typing_extensions.final
class DetectorModelIotEvents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INPUT_NAME_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    input_name: builtins.str
    @property
    def payload(self) -> global___DetectorModelPayload: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        input_name: builtins.str = ...,
        payload: global___DetectorModelPayload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_name", b"input_name", "payload", b"payload", "resource_info", b"resource_info"]) -> None: ...

global___DetectorModelIotEvents = DetectorModelIotEvents

@typing_extensions.final
class DetectorModelFirehose(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELIVERY_STREAM_NAME_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    SEPARATOR_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delivery_stream_name: builtins.str
    @property
    def payload(self) -> global___DetectorModelPayload: ...
    separator: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delivery_stream_name: builtins.str = ...,
        payload: global___DetectorModelPayload | None = ...,
        separator: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_stream_name", b"delivery_stream_name", "payload", b"payload", "resource_info", b"resource_info", "separator", b"separator"]) -> None: ...

global___DetectorModelFirehose = DetectorModelFirehose

@typing_extensions.final
class DetectorModelIotTopicPublish(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MQTT_TOPIC_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mqtt_topic: builtins.str
    @property
    def payload(self) -> global___DetectorModelPayload: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mqtt_topic: builtins.str = ...,
        payload: global___DetectorModelPayload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mqtt_topic", b"mqtt_topic", "payload", b"payload", "resource_info", b"resource_info"]) -> None: ...

global___DetectorModelIotTopicPublish = DetectorModelIotTopicPublish

@typing_extensions.final
class DetectorModelDynamoDB(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_FIELD_NUMBER: builtins.int
    RANGE_KEY_FIELD_FIELD_NUMBER: builtins.int
    HASH_KEY_FIELD_FIELD_NUMBER: builtins.int
    RANGE_KEY_VALUE_FIELD_NUMBER: builtins.int
    RANGE_KEY_TYPE_FIELD_NUMBER: builtins.int
    HASH_KEY_TYPE_FIELD_NUMBER: builtins.int
    HASH_KEY_VALUE_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    table_name: builtins.str
    payload_field: builtins.str
    range_key_field: builtins.str
    hash_key_field: builtins.str
    range_key_value: builtins.str
    range_key_type: builtins.str
    hash_key_type: builtins.str
    hash_key_value: builtins.str
    @property
    def payload(self) -> global___DetectorModelPayload: ...
    operation: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        table_name: builtins.str = ...,
        payload_field: builtins.str = ...,
        range_key_field: builtins.str = ...,
        hash_key_field: builtins.str = ...,
        range_key_value: builtins.str = ...,
        range_key_type: builtins.str = ...,
        hash_key_type: builtins.str = ...,
        hash_key_value: builtins.str = ...,
        payload: global___DetectorModelPayload | None = ...,
        operation: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash_key_field", b"hash_key_field", "hash_key_type", b"hash_key_type", "hash_key_value", b"hash_key_value", "operation", b"operation", "payload", b"payload", "payload_field", b"payload_field", "range_key_field", b"range_key_field", "range_key_type", b"range_key_type", "range_key_value", b"range_key_value", "resource_info", b"resource_info", "table_name", b"table_name"]) -> None: ...

global___DetectorModelDynamoDB = DetectorModelDynamoDB

@typing_extensions.final
class DetectorModelDynamoDBv2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    table_name: builtins.str
    @property
    def payload(self) -> global___DetectorModelPayload: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        table_name: builtins.str = ...,
        payload: global___DetectorModelPayload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info", "table_name", b"table_name"]) -> None: ...

global___DetectorModelDynamoDBv2 = DetectorModelDynamoDBv2

@typing_extensions.final
class DetectorModelAssetPropertyVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DOUBLE_VALUE_FIELD_NUMBER: builtins.int
    INTEGER_VALUE_FIELD_NUMBER: builtins.int
    BOOLEAN_VALUE_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    double_value: builtins.str
    integer_value: builtins.str
    boolean_value: builtins.str
    string_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        double_value: builtins.str = ...,
        integer_value: builtins.str = ...,
        boolean_value: builtins.str = ...,
        string_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boolean_value", b"boolean_value", "double_value", b"double_value", "integer_value", b"integer_value", "resource_info", b"resource_info", "string_value", b"string_value"]) -> None: ...

global___DetectorModelAssetPropertyVariant = DetectorModelAssetPropertyVariant

@typing_extensions.final
class DetectorModelAssetPropertyTimestamp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TIME_IN_SECONDS_FIELD_NUMBER: builtins.int
    OFFSET_IN_NANOS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    time_in_seconds: builtins.str
    offset_in_nanos: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        time_in_seconds: builtins.str = ...,
        offset_in_nanos: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["offset_in_nanos", b"offset_in_nanos", "resource_info", b"resource_info", "time_in_seconds", b"time_in_seconds"]) -> None: ...

global___DetectorModelAssetPropertyTimestamp = DetectorModelAssetPropertyTimestamp

@typing_extensions.final
class DetectorModelAssetPropertyValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    QUALITY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    quality: builtins.str
    @property
    def value(self) -> global___DetectorModelAssetPropertyVariant: ...
    @property
    def timestamp(self) -> global___DetectorModelAssetPropertyTimestamp: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        quality: builtins.str = ...,
        value: global___DetectorModelAssetPropertyVariant | None = ...,
        timestamp: global___DetectorModelAssetPropertyTimestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timestamp", b"timestamp", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["quality", b"quality", "resource_info", b"resource_info", "timestamp", b"timestamp", "value", b"value"]) -> None: ...

global___DetectorModelAssetPropertyValue = DetectorModelAssetPropertyValue

@typing_extensions.final
class DetectorModelIotSiteWise(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENTRY_ID_FIELD_NUMBER: builtins.int
    PROPERTY_ALIAS_FIELD_NUMBER: builtins.int
    PROPERTY_VALUE_FIELD_NUMBER: builtins.int
    ASSET_ID_FIELD_NUMBER: builtins.int
    PROPERTY_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    entry_id: builtins.str
    property_alias: builtins.str
    @property
    def property_value(self) -> global___DetectorModelAssetPropertyValue: ...
    asset_id: builtins.str
    property_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        entry_id: builtins.str = ...,
        property_alias: builtins.str = ...,
        property_value: global___DetectorModelAssetPropertyValue | None = ...,
        asset_id: builtins.str = ...,
        property_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["property_value", b"property_value", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["asset_id", b"asset_id", "entry_id", b"entry_id", "property_alias", b"property_alias", "property_id", b"property_id", "property_value", b"property_value", "resource_info", b"resource_info"]) -> None: ...

global___DetectorModelIotSiteWise = DetectorModelIotSiteWise

@typing_extensions.final
class DetectorModelResetTimer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TIMER_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    timer_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        timer_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timer_name", b"timer_name"]) -> None: ...

global___DetectorModelResetTimer = DetectorModelResetTimer

@typing_extensions.final
class DetectorModelSqs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USE_BASE64_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    QUEUE_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    use_base64: builtins.bool
    @property
    def payload(self) -> global___DetectorModelPayload: ...
    queue_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        use_base64: builtins.bool = ...,
        payload: global___DetectorModelPayload | None = ...,
        queue_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["payload", b"payload", "queue_url", b"queue_url", "resource_info", b"resource_info", "use_base64", b"use_base64"]) -> None: ...

global___DetectorModelSqs = DetectorModelSqs

@typing_extensions.final
class DetectorModelSns(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_ARN_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target_arn: builtins.str
    @property
    def payload(self) -> global___DetectorModelPayload: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_arn: builtins.str = ...,
        payload: global___DetectorModelPayload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info", "target_arn", b"target_arn"]) -> None: ...

global___DetectorModelSns = DetectorModelSns

@typing_extensions.final
class DetectorModelSetTimer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    TIMER_NAME_FIELD_NUMBER: builtins.int
    DURATION_EXPRESSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    seconds: builtins.int
    timer_name: builtins.str
    duration_expression: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        seconds: builtins.int = ...,
        timer_name: builtins.str = ...,
        duration_expression: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_expression", b"duration_expression", "resource_info", b"resource_info", "seconds", b"seconds", "timer_name", b"timer_name"]) -> None: ...

global___DetectorModelSetTimer = DetectorModelSetTimer

@typing_extensions.final
class DetectorModelClearTimer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TIMER_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    timer_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        timer_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timer_name", b"timer_name"]) -> None: ...

global___DetectorModelClearTimer = DetectorModelClearTimer

@typing_extensions.final
class DetectorModelLambda(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FUNCTION_ARN_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    function_arn: builtins.str
    @property
    def payload(self) -> global___DetectorModelPayload: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        function_arn: builtins.str = ...,
        payload: global___DetectorModelPayload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["payload", b"payload", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["function_arn", b"function_arn", "payload", b"payload", "resource_info", b"resource_info"]) -> None: ...

global___DetectorModelLambda = DetectorModelLambda

@typing_extensions.final
class DetectorModelSetVariable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VARIABLE_NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    variable_name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        variable_name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "value", b"value", "variable_name", b"variable_name"]) -> None: ...

global___DetectorModelSetVariable = DetectorModelSetVariable

@typing_extensions.final
class DetectorModelAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IOT_EVENTS_FIELD_NUMBER: builtins.int
    FIREHOSE_FIELD_NUMBER: builtins.int
    IOT_TOPIC_PUBLISH_FIELD_NUMBER: builtins.int
    DYNAMO_DB_FIELD_NUMBER: builtins.int
    DYNAMO_DBV2_FIELD_NUMBER: builtins.int
    IOT_SITE_WISE_FIELD_NUMBER: builtins.int
    RESET_TIMER_FIELD_NUMBER: builtins.int
    SQS_FIELD_NUMBER: builtins.int
    SNS_FIELD_NUMBER: builtins.int
    SET_TIMER_FIELD_NUMBER: builtins.int
    CLEAR_TIMER_FIELD_NUMBER: builtins.int
    LAMBDA_FIELD_NUMBER: builtins.int
    SET_VARIABLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def iot_events(self) -> global___DetectorModelIotEvents: ...
    @property
    def firehose(self) -> global___DetectorModelFirehose: ...
    @property
    def iot_topic_publish(self) -> global___DetectorModelIotTopicPublish: ...
    @property
    def dynamo_db(self) -> global___DetectorModelDynamoDB: ...
    @property
    def dynamo_dbv2(self) -> global___DetectorModelDynamoDBv2: ...
    @property
    def iot_site_wise(self) -> global___DetectorModelIotSiteWise: ...
    @property
    def reset_timer(self) -> global___DetectorModelResetTimer: ...
    @property
    def sqs(self) -> global___DetectorModelSqs: ...
    @property
    def sns(self) -> global___DetectorModelSns: ...
    @property
    def set_timer(self) -> global___DetectorModelSetTimer: ...
    @property
    def clear_timer(self) -> global___DetectorModelClearTimer: ...
    @property
    def set_variable(self) -> global___DetectorModelSetVariable: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        iot_events: global___DetectorModelIotEvents | None = ...,
        firehose: global___DetectorModelFirehose | None = ...,
        iot_topic_publish: global___DetectorModelIotTopicPublish | None = ...,
        dynamo_db: global___DetectorModelDynamoDB | None = ...,
        dynamo_dbv2: global___DetectorModelDynamoDBv2 | None = ...,
        iot_site_wise: global___DetectorModelIotSiteWise | None = ...,
        reset_timer: global___DetectorModelResetTimer | None = ...,
        sqs: global___DetectorModelSqs | None = ...,
        sns: global___DetectorModelSns | None = ...,
        set_timer: global___DetectorModelSetTimer | None = ...,
        clear_timer: global___DetectorModelClearTimer | None = ...,
        set_variable: global___DetectorModelSetVariable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["clear_timer", b"clear_timer", "dynamo_db", b"dynamo_db", "dynamo_dbv2", b"dynamo_dbv2", "firehose", b"firehose", "iot_events", b"iot_events", "iot_site_wise", b"iot_site_wise", "iot_topic_publish", b"iot_topic_publish", "lambda", b"lambda", "reset_timer", b"reset_timer", "resource_info", b"resource_info", "set_timer", b"set_timer", "set_variable", b"set_variable", "sns", b"sns", "sqs", b"sqs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["clear_timer", b"clear_timer", "dynamo_db", b"dynamo_db", "dynamo_dbv2", b"dynamo_dbv2", "firehose", b"firehose", "iot_events", b"iot_events", "iot_site_wise", b"iot_site_wise", "iot_topic_publish", b"iot_topic_publish", "lambda", b"lambda", "reset_timer", b"reset_timer", "resource_info", b"resource_info", "set_timer", b"set_timer", "set_variable", b"set_variable", "sns", b"sns", "sqs", b"sqs"]) -> None: ...

global___DetectorModelAction = DetectorModelAction

@typing_extensions.final
class DetectorModelEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    EVENT_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    condition: builtins.str
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetectorModelAction]: ...
    event_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        condition: builtins.str = ...,
        actions: collections.abc.Iterable[global___DetectorModelAction] | None = ...,
        event_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "condition", b"condition", "event_name", b"event_name", "resource_info", b"resource_info"]) -> None: ...

global___DetectorModelEvent = DetectorModelEvent

@typing_extensions.final
class DetectorModelTransitionEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    NEXT_STATE_FIELD_NUMBER: builtins.int
    EVENT_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    condition: builtins.str
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetectorModelAction]: ...
    next_state: builtins.str
    event_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        condition: builtins.str = ...,
        actions: collections.abc.Iterable[global___DetectorModelAction] | None = ...,
        next_state: builtins.str = ...,
        event_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "condition", b"condition", "event_name", b"event_name", "next_state", b"next_state", "resource_info", b"resource_info"]) -> None: ...

global___DetectorModelTransitionEvent = DetectorModelTransitionEvent

@typing_extensions.final
class DetectorModelOnInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    TRANSITION_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetectorModelEvent]: ...
    @property
    def transition_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetectorModelTransitionEvent]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        events: collections.abc.Iterable[global___DetectorModelEvent] | None = ...,
        transition_events: collections.abc.Iterable[global___DetectorModelTransitionEvent] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events", "resource_info", b"resource_info", "transition_events", b"transition_events"]) -> None: ...

global___DetectorModelOnInput = DetectorModelOnInput

@typing_extensions.final
class DetectorModelOnExit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetectorModelEvent]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        events: collections.abc.Iterable[global___DetectorModelEvent] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events", "resource_info", b"resource_info"]) -> None: ...

global___DetectorModelOnExit = DetectorModelOnExit

@typing_extensions.final
class DetectorModelOnEnter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetectorModelEvent]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        events: collections.abc.Iterable[global___DetectorModelEvent] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events", "resource_info", b"resource_info"]) -> None: ...

global___DetectorModelOnEnter = DetectorModelOnEnter

@typing_extensions.final
class DetectorModelState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ON_INPUT_FIELD_NUMBER: builtins.int
    ON_EXIT_FIELD_NUMBER: builtins.int
    STATE_NAME_FIELD_NUMBER: builtins.int
    ON_ENTER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def on_input(self) -> global___DetectorModelOnInput: ...
    @property
    def on_exit(self) -> global___DetectorModelOnExit: ...
    state_name: builtins.str
    @property
    def on_enter(self) -> global___DetectorModelOnEnter: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        on_input: global___DetectorModelOnInput | None = ...,
        on_exit: global___DetectorModelOnExit | None = ...,
        state_name: builtins.str = ...,
        on_enter: global___DetectorModelOnEnter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["on_enter", b"on_enter", "on_exit", b"on_exit", "on_input", b"on_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["on_enter", b"on_enter", "on_exit", b"on_exit", "on_input", b"on_input", "resource_info", b"resource_info", "state_name", b"state_name"]) -> None: ...

global___DetectorModelState = DetectorModelState

@typing_extensions.final
class DetectorModelDetectorModelDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STATES_FIELD_NUMBER: builtins.int
    INITIAL_STATE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetectorModelState]: ...
    initial_state_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        states: collections.abc.Iterable[global___DetectorModelState] | None = ...,
        initial_state_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["initial_state_name", b"initial_state_name", "resource_info", b"resource_info", "states", b"states"]) -> None: ...

global___DetectorModelDetectorModelDefinition = DetectorModelDetectorModelDefinition

@typing_extensions.final
class DetectorModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DETECTOR_MODEL_DEFINITION_FIELD_NUMBER: builtins.int
    EVALUATION_METHOD_FIELD_NUMBER: builtins.int
    DETECTOR_MODEL_NAME_FIELD_NUMBER: builtins.int
    DETECTOR_MODEL_DESCRIPTION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def detector_model_definition(self) -> global___DetectorModelDetectorModelDefinition: ...
    evaluation_method: builtins.str
    detector_model_name: builtins.str
    detector_model_description: builtins.str
    key: builtins.str
    role_arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        detector_model_definition: global___DetectorModelDetectorModelDefinition | None = ...,
        evaluation_method: builtins.str = ...,
        detector_model_name: builtins.str = ...,
        detector_model_description: builtins.str = ...,
        key: builtins.str = ...,
        role_arn: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["detector_model_definition", b"detector_model_definition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["detector_model_definition", b"detector_model_definition", "detector_model_description", b"detector_model_description", "detector_model_name", b"detector_model_name", "evaluation_method", b"evaluation_method", "key", b"key", "resource_info", b"resource_info", "role_arn", b"role_arn", "tags", b"tags"]) -> None: ...

global___DetectorModel = DetectorModel

@typing_extensions.final
class IoTEvents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETECTOR_MODEL_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    @property
    def detector_model(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetectorModel]: ...
    @property
    def input(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Input]: ...
    def __init__(
        self,
        *,
        detector_model: collections.abc.Iterable[global___DetectorModel] | None = ...,
        input: collections.abc.Iterable[global___Input] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["detector_model", b"detector_model", "input", b"input"]) -> None: ...

global___IoTEvents = IoTEvents

@typing_extensions.final
class InputAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    JSON_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    json_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        json_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["json_path", b"json_path", "resource_info", b"resource_info"]) -> None: ...

global___InputAttribute = InputAttribute

@typing_extensions.final
class InputInputDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InputAttribute]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attributes: collections.abc.Iterable[global___InputAttribute] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "resource_info", b"resource_info"]) -> None: ...

global___InputInputDefinition = InputInputDefinition

@typing_extensions.final
class Input(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INPUT_DEFINITION_FIELD_NUMBER: builtins.int
    INPUT_NAME_FIELD_NUMBER: builtins.int
    INPUT_DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def input_definition(self) -> global___InputInputDefinition: ...
    input_name: builtins.str
    input_description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        input_definition: global___InputInputDefinition | None = ...,
        input_name: builtins.str = ...,
        input_description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input_definition", b"input_definition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_definition", b"input_definition", "input_description", b"input_description", "input_name", b"input_name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Input = Input



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_s3.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61ws/aws_s3.proto\x12\x12oak9.tython.aws.s3\x1a\x13shared/shared.proto\"f\n\x1b\x41\x63\x63\x65ssPointVpcConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06vpc_id\x18\x02 \x01(\t\"\xd9\x01\n)AccessPointPublicAccessBlockConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x62lock_public_acls\x18\x02 \x01(\x08\x12\x1a\n\x12ignore_public_acls\x18\x03 \x01(\x08\x12\x1b\n\x13\x62lock_public_policy\x18\x04 \x01(\x08\x12\x1f\n\x17restrict_public_buckets\x18\x05 \x01(\x08\"\xb4\x04\n\x0b\x41\x63\x63\x65ssPoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12J\n\x11vpc_configuration\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.s3.AccessPointVpcConfiguration\x12h\n!public_access_block_configuration\x18\x05 \x01(\x0b\x32=.oak9.tython.aws.s3.AccessPointPublicAccessBlockConfiguration\x12;\n\x06policy\x18\x06 \x03(\x0b\x32+.oak9.tython.aws.s3.AccessPoint.PolicyEntry\x12H\n\rpolicy_status\x18\x07 \x03(\x0b\x32\x31.oak9.tython.aws.s3.AccessPoint.PolicyStatusEntry\x12\x16\n\x0enetwork_origin\x18\x08 \x01(\t\x12\x15\n\rcreation_date\x18\t \x01(\t\x1a-\n\x0bPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11PolicyStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\x02S3\x12\x35\n\x0c\x61\x63\x63\x65ss_point\x18\x01 \x01(\x0b\x32\x1f.oak9.tython.aws.s3.AccessPoint\x12*\n\x06\x62ucket\x18\x02 \x01(\x0b\x32\x1a.oak9.tython.aws.s3.Bucket\x12\x37\n\rbucket_policy\x18\x03 \x01(\x0b\x32 .oak9.tython.aws.s3.BucketPolicy\"u\n\x1d\x42ucketAccelerateConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x61\x63\x63\x65leration_status\x18\x02 \x01(\t\"\x9b\x01\n\x11\x42ucketDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x62ucket_account_id\x18\x02 \x01(\t\x12\x12\n\nbucket_arn\x18\x03 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\"\xa6\x01\n\x10\x42ucketDataExport\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12:\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.s3.BucketDestination\x12\x1d\n\x15output_schema_version\x18\x03 \x01(\t\"\x90\x01\n\x1a\x42ucketStorageClassAnalysis\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x39\n\x0b\x64\x61ta_export\x18\x02 \x01(\x0b\x32$.oak9.tython.aws.s3.BucketDataExport\"f\n\x0f\x42ucketTagFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfd\x01\n\x1c\x42ucketAnalyticsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12N\n\x16storage_class_analysis\x18\x04 \x01(\x0b\x32..oak9.tython.aws.s3.BucketStorageClassAnalysis\x12\x38\n\x0btag_filters\x18\x05 \x03(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\"\x90\x01\n#BucketServerSideEncryptionByDefault\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11kms_master_key_id\x18\x02 \x01(\t\x12\x15\n\rsse_algorithm\x18\x03 \x01(\t\"\xbd\x01\n\x1e\x42ucketServerSideEncryptionRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n!server_side_encryption_by_default\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.s3.BucketServerSideEncryptionByDefault\"\xb3\x01\n\x16\x42ucketBucketEncryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n$server_side_encryption_configuration\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.s3.BucketServerSideEncryptionRule\"\xca\x01\n\x0e\x42ucketCorsRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61llowed_headers\x18\x02 \x03(\t\x12\x17\n\x0f\x61llowed_methods\x18\x03 \x03(\t\x12\x17\n\x0f\x61llowed_origins\x18\x04 \x03(\t\x12\x17\n\x0f\x65xposed_headers\x18\x05 \x03(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0f\n\x07max_age\x18\x07 \x01(\x05\"\x8a\x01\n\x17\x42ucketCorsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x36\n\ncors_rules\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.s3.BucketCorsRule\"\x97\x02\n\x1c\x42ucketInventoryConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12:\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.s3.BucketDestination\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12 \n\x18included_object_versions\x18\x05 \x01(\t\x12\x17\n\x0foptional_fields\x18\x06 \x03(\t\x12\x0e\n\x06prefix\x18\x07 \x01(\t\x12\x1a\n\x12schedule_frequency\x18\x08 \x01(\t\"~\n$BucketAbortIncompleteMultipartUpload\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x61ys_after_initiation\x18\x02 \x01(\x05\"\x8f\x01\n!BucketNoncurrentVersionTransition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rstorage_class\x18\x02 \x01(\t\x12\x1a\n\x12transition_in_days\x18\x03 \x01(\x05\"\x97\x01\n\x10\x42ucketTransition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rstorage_class\x18\x02 \x01(\t\x12\x17\n\x0ftransition_date\x18\x03 \x01(\t\x12\x1a\n\x12transition_in_days\x18\x04 \x01(\x05\"\xa6\x05\n\nBucketRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n!abort_incomplete_multipart_upload\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.s3.BucketAbortIncompleteMultipartUpload\x12\x17\n\x0f\x65xpiration_date\x18\x03 \x01(\t\x12\x1a\n\x12\x65xpiration_in_days\x18\x04 \x01(\x05\x12\n\n\x02id\x18\x05 \x01(\t\x12-\n%noncurrent_version_expiration_in_days\x18\x06 \x01(\x05\x12\\\n\x1dnoncurrent_version_transition\x18\x07 \x01(\x0b\x32\x35.oak9.tython.aws.s3.BucketNoncurrentVersionTransition\x12]\n\x1enoncurrent_version_transitions\x18\x08 \x03(\x0b\x32\x35.oak9.tython.aws.s3.BucketNoncurrentVersionTransition\x12\x0e\n\x06prefix\x18\t \x01(\t\x12\x0e\n\x06status\x18\n \x01(\t\x12\x38\n\x0btag_filters\x18\x0b \x03(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\x12\x38\n\ntransition\x18\x0c \x01(\x0b\x32$.oak9.tython.aws.s3.BucketTransition\x12\x39\n\x0btransitions\x18\r \x03(\x0b\x32$.oak9.tython.aws.s3.BucketTransition\"\x86\x01\n\x1c\x42ucketLifecycleConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12-\n\x05rules\x18\x02 \x03(\x0b\x32\x1e.oak9.tython.aws.s3.BucketRule\"\x8f\x01\n\x1a\x42ucketLoggingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x64\x65stination_bucket_name\x18\x02 \x01(\t\x12\x17\n\x0flog_file_prefix\x18\x03 \x01(\t\"\xab\x01\n\x1a\x42ucketMetricsConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x38\n\x0btag_filters\x18\x04 \x03(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\"h\n\x10\x42ucketFilterRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x81\x01\n\x11\x42ucketS3KeyFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x33\n\x05rules\x18\x02 \x03(\x0b\x32$.oak9.tython.aws.s3.BucketFilterRule\"\x8a\x01\n\x18\x42ucketNotificationFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x35\n\x06s3_key\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.s3.BucketS3KeyFilter\"\xb3\x01\n\x19\x42ucketLambdaConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65vent\x18\x02 \x01(\t\x12<\n\x06\x66ilter\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.s3.BucketNotificationFilter\x12\x10\n\x08\x66unction\x18\x04 \x01(\t\"\xaf\x01\n\x18\x42ucketQueueConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65vent\x18\x02 \x01(\t\x12<\n\x06\x66ilter\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.s3.BucketNotificationFilter\x12\r\n\x05queue\x18\x04 \x01(\t\"\xaf\x01\n\x18\x42ucketTopicConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65vent\x18\x02 \x01(\t\x12<\n\x06\x66ilter\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.s3.BucketNotificationFilter\x12\r\n\x05topic\x18\x04 \x01(\t\"\xc0\x02\n\x1f\x42ucketNotificationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x15lambda_configurations\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.s3.BucketLambdaConfiguration\x12J\n\x14queue_configurations\x18\x03 \x03(\x0b\x32,.oak9.tython.aws.s3.BucketQueueConfiguration\x12J\n\x14topic_configurations\x18\x04 \x03(\x0b\x32,.oak9.tython.aws.s3.BucketTopicConfiguration\"|\n\x16\x42ucketDefaultRetention\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ys\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\r\n\x05years\x18\x04 \x01(\x05\"\x96\x01\n\x14\x42ucketObjectLockRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x11\x64\x65\x66\x61ult_retention\x18\x02 \x01(\x0b\x32*.oak9.tython.aws.s3.BucketDefaultRetention\"\xad\x01\n\x1d\x42ucketObjectLockConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13object_lock_enabled\x18\x02 \x01(\t\x12\x36\n\x04rule\x18\x03 \x01(\x0b\x32(.oak9.tython.aws.s3.BucketObjectLockRule\"\xd4\x01\n$BucketPublicAccessBlockConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x62lock_public_acls\x18\x02 \x01(\x08\x12\x1b\n\x13\x62lock_public_policy\x18\x03 \x01(\x08\x12\x1a\n\x12ignore_public_acls\x18\x04 \x01(\x08\x12\x1f\n\x17restrict_public_buckets\x18\x05 \x01(\x08\"h\n\x1d\x42ucketDeleteMarkerReplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\"h\n\x1e\x42ucketAccessControlTranslation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05owner\x18\x02 \x01(\t\"t\n\x1d\x42ucketEncryptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12replica_kms_key_id\x18\x02 \x01(\t\"f\n\x1a\x42ucketReplicationTimeValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07minutes\x18\x02 \x01(\x05\"\xa1\x01\n\rBucketMetrics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x0f\x65vent_threshold\x18\x02 \x01(\x0b\x32..oak9.tython.aws.s3.BucketReplicationTimeValue\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x9e\x01\n\x15\x42ucketReplicationTime\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12<\n\x04time\x18\x03 \x01(\x0b\x32..oak9.tython.aws.s3.BucketReplicationTimeValue\"\xb5\x03\n\x1c\x42ucketReplicationDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x1a\x61\x63\x63\x65ss_control_translation\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.s3.BucketAccessControlTranslation\x12\x0f\n\x07\x61\x63\x63ount\x18\x03 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x04 \x01(\t\x12S\n\x18\x65ncryption_configuration\x18\x05 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketEncryptionConfiguration\x12\x32\n\x07metrics\x18\x06 \x01(\x0b\x32!.oak9.tython.aws.s3.BucketMetrics\x12\x43\n\x10replication_time\x18\x07 \x01(\x0b\x32).oak9.tython.aws.s3.BucketReplicationTime\x12\x15\n\rstorage_class\x18\x08 \x01(\t\"\xa5\x01\n BucketReplicationRuleAndOperator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x38\n\x0btag_filters\x18\x03 \x03(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\"\xe2\x01\n\x1b\x42ucketReplicationRuleFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x03\x61nd\x18\x02 \x01(\x0b\x32\x34.oak9.tython.aws.s3.BucketReplicationRuleAndOperator\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x37\n\ntag_filter\x18\x04 \x01(\x0b\x32#.oak9.tython.aws.s3.BucketTagFilter\"g\n\x1c\x42ucketSseKmsEncryptedObjects\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\"\xad\x01\n\x1d\x42ucketSourceSelectionCriteria\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x19sse_kms_encrypted_objects\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.s3.BucketSseKmsEncryptedObjects\"\xc2\x03\n\x15\x42ucketReplicationRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x19\x64\x65lete_marker_replication\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketDeleteMarkerReplication\x12\x45\n\x0b\x64\x65stination\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.s3.BucketReplicationDestination\x12?\n\x06\x66ilter\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.s3.BucketReplicationRuleFilter\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0e\n\x06prefix\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\x05\x12T\n\x19source_selection_criteria\x18\x08 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketSourceSelectionCriteria\x12\x0e\n\x06status\x18\t \x01(\t\"\xa1\x01\n\x1e\x42ucketReplicationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x38\n\x05rules\x18\x03 \x03(\x0b\x32).oak9.tython.aws.s3.BucketReplicationRule\"h\n\x1d\x42ucketVersioningConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\"{\n\x1b\x42ucketRedirectAllRequestsTo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\thost_name\x18\x02 \x01(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t\"\xc9\x01\n\x12\x42ucketRedirectRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\thost_name\x18\x02 \x01(\t\x12\x1a\n\x12http_redirect_code\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x1f\n\x17replace_key_prefix_with\x18\x05 \x01(\t\x12\x18\n\x10replace_key_with\x18\x06 \x01(\t\"\x99\x01\n\x1a\x42ucketRoutingRuleCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1fhttp_error_code_returned_equals\x18\x02 \x01(\t\x12\x19\n\x11key_prefix_equals\x18\x03 \x01(\t\"\xdb\x01\n\x11\x42ucketRoutingRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\rredirect_rule\x18\x02 \x01(\x0b\x32&.oak9.tython.aws.s3.BucketRedirectRule\x12N\n\x16routing_rule_condition\x18\x03 \x01(\x0b\x32..oak9.tython.aws.s3.BucketRoutingRuleCondition\"\x96\x02\n\x1a\x42ucketWebsiteConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x65rror_document\x18\x02 \x01(\t\x12\x16\n\x0eindex_document\x18\x03 \x01(\t\x12Q\n\x18redirect_all_requests_to\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.s3.BucketRedirectAllRequestsTo\x12<\n\rrouting_rules\x18\x05 \x03(\x0b\x32%.oak9.tython.aws.s3.BucketRoutingRule\"\xfd\x0b\n\x06\x42ucket\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x18\x61\x63\x63\x65lerate_configuration\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketAccelerateConfiguration\x12\x16\n\x0e\x61\x63\x63\x65ss_control\x18\x03 \x01(\t\x12R\n\x18\x61nalytics_configurations\x18\x04 \x03(\x0b\x32\x30.oak9.tython.aws.s3.BucketAnalyticsConfiguration\x12\x45\n\x11\x62ucket_encryption\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.s3.BucketBucketEncryption\x12\x13\n\x0b\x62ucket_name\x18\x06 \x01(\t\x12G\n\x12\x63ors_configuration\x18\x07 \x01(\x0b\x32+.oak9.tython.aws.s3.BucketCorsConfiguration\x12R\n\x18inventory_configurations\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.s3.BucketInventoryConfiguration\x12Q\n\x17lifecycle_configuration\x18\t \x01(\x0b\x32\x30.oak9.tython.aws.s3.BucketLifecycleConfiguration\x12M\n\x15logging_configuration\x18\n \x01(\x0b\x32..oak9.tython.aws.s3.BucketLoggingConfiguration\x12N\n\x16metrics_configurations\x18\x0b \x03(\x0b\x32..oak9.tython.aws.s3.BucketMetricsConfiguration\x12W\n\x1anotification_configuration\x18\x0c \x01(\x0b\x32\x33.oak9.tython.aws.s3.BucketNotificationConfiguration\x12T\n\x19object_lock_configuration\x18\r \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketObjectLockConfiguration\x12\x1b\n\x13object_lock_enabled\x18\x0e \x01(\x08\x12\x63\n!public_access_block_configuration\x18\x0f \x01(\x0b\x32\x38.oak9.tython.aws.s3.BucketPublicAccessBlockConfiguration\x12U\n\x19replication_configuration\x18\x10 \x01(\x0b\x32\x32.oak9.tython.aws.s3.BucketReplicationConfiguration\x12\x32\n\x04tags\x18\x11 \x03(\x0b\x32$.oak9.tython.aws.s3.Bucket.TagsEntry\x12S\n\x18versioning_configuration\x18\x12 \x01(\x0b\x32\x31.oak9.tython.aws.s3.BucketVersioningConfiguration\x12M\n\x15website_configuration\x18\x13 \x01(\x0b\x32..oak9.tython.aws.s3.BucketWebsiteConfiguration\x12\x38\n\nversioning\x18\x14 \x01(\x0b\x32$.oak9.tython.aws.s3.BucketVersioning\x12G\n\x12ownership_controls\x18\x15 \x01(\x0b\x32+.oak9.tython.aws.s3.BucketOwnershipControls\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"#\n\x10\x42ucketVersioning\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"p\n\x1b\x42ucketOwnershipControlsRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10object_ownership\x18\x02 \x01(\t\"\x92\x01\n\x17\x42ucketOwnershipControls\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12>\n\x05rules\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.s3.BucketOwnershipControlsRule\"p\n\x0c\x42ucketPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_s3_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCESSPOINT_POLICYENTRY._options = None
  _ACCESSPOINT_POLICYENTRY._serialized_options = b'8\001'
  _ACCESSPOINT_POLICYSTATUSENTRY._options = None
  _ACCESSPOINT_POLICYSTATUSENTRY._serialized_options = b'8\001'
  _BUCKET_TAGSENTRY._options = None
  _BUCKET_TAGSENTRY._serialized_options = b'8\001'
  _ACCESSPOINTVPCCONFIGURATION._serialized_start=61
  _ACCESSPOINTVPCCONFIGURATION._serialized_end=163
  _ACCESSPOINTPUBLICACCESSBLOCKCONFIGURATION._serialized_start=166
  _ACCESSPOINTPUBLICACCESSBLOCKCONFIGURATION._serialized_end=383
  _ACCESSPOINT._serialized_start=386
  _ACCESSPOINT._serialized_end=950
  _ACCESSPOINT_POLICYENTRY._serialized_start=852
  _ACCESSPOINT_POLICYENTRY._serialized_end=897
  _ACCESSPOINT_POLICYSTATUSENTRY._serialized_start=899
  _ACCESSPOINT_POLICYSTATUSENTRY._serialized_end=950
  _S3._serialized_start=953
  _S3._serialized_end=1113
  _BUCKETACCELERATECONFIGURATION._serialized_start=1115
  _BUCKETACCELERATECONFIGURATION._serialized_end=1232
  _BUCKETDESTINATION._serialized_start=1235
  _BUCKETDESTINATION._serialized_end=1390
  _BUCKETDATAEXPORT._serialized_start=1393
  _BUCKETDATAEXPORT._serialized_end=1559
  _BUCKETSTORAGECLASSANALYSIS._serialized_start=1562
  _BUCKETSTORAGECLASSANALYSIS._serialized_end=1706
  _BUCKETTAGFILTER._serialized_start=1708
  _BUCKETTAGFILTER._serialized_end=1810
  _BUCKETANALYTICSCONFIGURATION._serialized_start=1813
  _BUCKETANALYTICSCONFIGURATION._serialized_end=2066
  _BUCKETSERVERSIDEENCRYPTIONBYDEFAULT._serialized_start=2069
  _BUCKETSERVERSIDEENCRYPTIONBYDEFAULT._serialized_end=2213
  _BUCKETSERVERSIDEENCRYPTIONRULE._serialized_start=2216
  _BUCKETSERVERSIDEENCRYPTIONRULE._serialized_end=2405
  _BUCKETBUCKETENCRYPTION._serialized_start=2408
  _BUCKETBUCKETENCRYPTION._serialized_end=2587
  _BUCKETCORSRULE._serialized_start=2590
  _BUCKETCORSRULE._serialized_end=2792
  _BUCKETCORSCONFIGURATION._serialized_start=2795
  _BUCKETCORSCONFIGURATION._serialized_end=2933
  _BUCKETINVENTORYCONFIGURATION._serialized_start=2936
  _BUCKETINVENTORYCONFIGURATION._serialized_end=3215
  _BUCKETABORTINCOMPLETEMULTIPARTUPLOAD._serialized_start=3217
  _BUCKETABORTINCOMPLETEMULTIPARTUPLOAD._serialized_end=3343
  _BUCKETNONCURRENTVERSIONTRANSITION._serialized_start=3346
  _BUCKETNONCURRENTVERSIONTRANSITION._serialized_end=3489
  _BUCKETTRANSITION._serialized_start=3492
  _BUCKETTRANSITION._serialized_end=3643
  _BUCKETRULE._serialized_start=3646
  _BUCKETRULE._serialized_end=4324
  _BUCKETLIFECYCLECONFIGURATION._serialized_start=4327
  _BUCKETLIFECYCLECONFIGURATION._serialized_end=4461
  _BUCKETLOGGINGCONFIGURATION._serialized_start=4464
  _BUCKETLOGGINGCONFIGURATION._serialized_end=4607
  _BUCKETMETRICSCONFIGURATION._serialized_start=4610
  _BUCKETMETRICSCONFIGURATION._serialized_end=4781
  _BUCKETFILTERRULE._serialized_start=4783
  _BUCKETFILTERRULE._serialized_end=4887
  _BUCKETS3KEYFILTER._serialized_start=4890
  _BUCKETS3KEYFILTER._serialized_end=5019
  _BUCKETNOTIFICATIONFILTER._serialized_start=5022
  _BUCKETNOTIFICATIONFILTER._serialized_end=5160
  _BUCKETLAMBDACONFIGURATION._serialized_start=5163
  _BUCKETLAMBDACONFIGURATION._serialized_end=5342
  _BUCKETQUEUECONFIGURATION._serialized_start=5345
  _BUCKETQUEUECONFIGURATION._serialized_end=5520
  _BUCKETTOPICCONFIGURATION._serialized_start=5523
  _BUCKETTOPICCONFIGURATION._serialized_end=5698
  _BUCKETNOTIFICATIONCONFIGURATION._serialized_start=5701
  _BUCKETNOTIFICATIONCONFIGURATION._serialized_end=6021
  _BUCKETDEFAULTRETENTION._serialized_start=6023
  _BUCKETDEFAULTRETENTION._serialized_end=6147
  _BUCKETOBJECTLOCKRULE._serialized_start=6150
  _BUCKETOBJECTLOCKRULE._serialized_end=6300
  _BUCKETOBJECTLOCKCONFIGURATION._serialized_start=6303
  _BUCKETOBJECTLOCKCONFIGURATION._serialized_end=6476
  _BUCKETPUBLICACCESSBLOCKCONFIGURATION._serialized_start=6479
  _BUCKETPUBLICACCESSBLOCKCONFIGURATION._serialized_end=6691
  _BUCKETDELETEMARKERREPLICATION._serialized_start=6693
  _BUCKETDELETEMARKERREPLICATION._serialized_end=6797
  _BUCKETACCESSCONTROLTRANSLATION._serialized_start=6799
  _BUCKETACCESSCONTROLTRANSLATION._serialized_end=6903
  _BUCKETENCRYPTIONCONFIGURATION._serialized_start=6905
  _BUCKETENCRYPTIONCONFIGURATION._serialized_end=7021
  _BUCKETREPLICATIONTIMEVALUE._serialized_start=7023
  _BUCKETREPLICATIONTIMEVALUE._serialized_end=7125
  _BUCKETMETRICS._serialized_start=7128
  _BUCKETMETRICS._serialized_end=7289
  _BUCKETREPLICATIONTIME._serialized_start=7292
  _BUCKETREPLICATIONTIME._serialized_end=7450
  _BUCKETREPLICATIONDESTINATION._serialized_start=7453
  _BUCKETREPLICATIONDESTINATION._serialized_end=7890
  _BUCKETREPLICATIONRULEANDOPERATOR._serialized_start=7893
  _BUCKETREPLICATIONRULEANDOPERATOR._serialized_end=8058
  _BUCKETREPLICATIONRULEFILTER._serialized_start=8061
  _BUCKETREPLICATIONRULEFILTER._serialized_end=8287
  _BUCKETSSEKMSENCRYPTEDOBJECTS._serialized_start=8289
  _BUCKETSSEKMSENCRYPTEDOBJECTS._serialized_end=8392
  _BUCKETSOURCESELECTIONCRITERIA._serialized_start=8395
  _BUCKETSOURCESELECTIONCRITERIA._serialized_end=8568
  _BUCKETREPLICATIONRULE._serialized_start=8571
  _BUCKETREPLICATIONRULE._serialized_end=9021
  _BUCKETREPLICATIONCONFIGURATION._serialized_start=9024
  _BUCKETREPLICATIONCONFIGURATION._serialized_end=9185
  _BUCKETVERSIONINGCONFIGURATION._serialized_start=9187
  _BUCKETVERSIONINGCONFIGURATION._serialized_end=9291
  _BUCKETREDIRECTALLREQUESTSTO._serialized_start=9293
  _BUCKETREDIRECTALLREQUESTSTO._serialized_end=9416
  _BUCKETREDIRECTRULE._serialized_start=9419
  _BUCKETREDIRECTRULE._serialized_end=9620
  _BUCKETROUTINGRULECONDITION._serialized_start=9623
  _BUCKETROUTINGRULECONDITION._serialized_end=9776
  _BUCKETROUTINGRULE._serialized_start=9779
  _BUCKETROUTINGRULE._serialized_end=9998
  _BUCKETWEBSITECONFIGURATION._serialized_start=10001
  _BUCKETWEBSITECONFIGURATION._serialized_end=10279
  _BUCKET._serialized_start=10282
  _BUCKET._serialized_end=11815
  _BUCKET_TAGSENTRY._serialized_start=11772
  _BUCKET_TAGSENTRY._serialized_end=11815
  _BUCKETVERSIONING._serialized_start=11817
  _BUCKETVERSIONING._serialized_end=11852
  _BUCKETOWNERSHIPCONTROLSRULE._serialized_start=11854
  _BUCKETOWNERSHIPCONTROLSRULE._serialized_end=11966
  _BUCKETOWNERSHIPCONTROLS._serialized_start=11969
  _BUCKETOWNERSHIPCONTROLS._serialized_end=12115
  _BUCKETPOLICY._serialized_start=12117
  _BUCKETPOLICY._serialized_end=12229
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_pubsub_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_pubsub_pb2 as gcp_dot_gcp__pubsub__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"gcp/gcp_google_pubsub_bundle.proto\x12$oak9.tython.gcp.google_pubsub_bundle\x1a\x13shared/shared.proto\x1a\x14gcp/gcp_pubsub.proto\"\xd7\x05\n\x0cGooglePubsub\x12;\n\rpubsub_schema\x18\x01 \x01(\x0b\x32$.oak9.tython.gcp.pubsub.PubsubSchema\x12G\n\x13pubsub_subscription\x18\x02 \x03(\x0b\x32*.oak9.tython.gcp.pubsub.PubsubSubscription\x12]\n\x1fpubsub_subscription_iam_binding\x18\x03 \x03(\x0b\x32\x34.oak9.tython.gcp.pubsub.PubsubSubscriptionIamBinding\x12[\n\x1epubsub_subscription_iam_member\x18\x04 \x03(\x0b\x32\x33.oak9.tython.gcp.pubsub.PubsubSubscriptionIamMember\x12[\n\x1epubsub_subscription_iam_policy\x18\x05 \x03(\x0b\x32\x33.oak9.tython.gcp.pubsub.PubsubSubscriptionIamPolicy\x12\x39\n\x0cpubsub_topic\x18\x06 \x01(\x0b\x32#.oak9.tython.gcp.pubsub.PubsubTopic\x12O\n\x18pubsub_topic_iam_binding\x18\x07 \x03(\x0b\x32-.oak9.tython.gcp.pubsub.PubsubTopicIamBinding\x12M\n\x17pubsub_topic_iam_member\x18\x08 \x03(\x0b\x32,.oak9.tython.gcp.pubsub.PubsubTopicIamMember\x12M\n\x17pubsub_topic_iam_policy\x18\t \x03(\x0b\x32,.oak9.tython.gcp.pubsub.PubsubTopicIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_pubsub_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEPUBSUB._serialized_start=120
  _GOOGLEPUBSUB._serialized_end=847
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_global.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_global.proto\x12\x1eoak9.tython.gcp.compute_global\x1a\x13shared/shared.proto\"?\n\x1d\x43omputeGlobalAddressXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x83\x03\n\x14\x43omputeGlobalAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x02 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x12\n\nip_version\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07network\x18\x08 \x01(\t\x12\x15\n\rprefix_length\x18\t \x01(\x01\x12\x0f\n\x07project\x18\n \x01(\t\x12\x0f\n\x07purpose\x18\x0b \x01(\t\x12\x11\n\tself_link\x18\x0c \x01(\t\x12O\n\x08timeouts\x18\r \x01(\x0b\x32=.oak9.tython.gcp.compute_global.ComputeGlobalAddressXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n8ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xbd\x01\n+ComputeGlobalForwardingRuleXMetadataFilters\x12\x1d\n\x15\x66ilter_match_criteria\x18\x01 \x01(\t\x12o\n\rfilter_labels\x18\x02 \x03(\x0b\x32X.oak9.tython.gcp.compute_global.ComputeGlobalForwardingRuleXMetadataFiltersXFilterLabels\"V\n$ComputeGlobalForwardingRuleXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x05\n\x1b\x43omputeGlobalForwardingRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\nip_address\x18\x03 \x01(\t\x12\x13\n\x0bip_protocol\x18\x04 \x01(\t\x12\x12\n\nip_version\x18\x05 \x01(\t\x12\x19\n\x11label_fingerprint\x18\x06 \x01(\t\x12W\n\x06labels\x18\x07 \x03(\x0b\x32G.oak9.tython.gcp.compute_global.ComputeGlobalForwardingRule.LabelsEntry\x12\x1d\n\x15load_balancing_scheme\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07network\x18\n \x01(\t\x12\x12\n\nport_range\x18\x0b \x01(\t\x12\x0f\n\x07project\x18\x0c \x01(\t\x12\x19\n\x11psc_connection_id\x18\r \x01(\t\x12\x1d\n\x15psc_connection_status\x18\x0e \x01(\t\x12\x11\n\tself_link\x18\x0f \x01(\t\x12\x0e\n\x06target\x18\x10 \x01(\t\x12\x65\n\x10metadata_filters\x18\x11 \x03(\x0b\x32K.oak9.tython.gcp.compute_global.ComputeGlobalForwardingRuleXMetadataFilters\x12V\n\x08timeouts\x18\x12 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_global.ComputeGlobalForwardingRuleXTimeouts\x12\x37\n\rresource_info\x18\x13 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n%ComputeGlobalNetworkEndpointXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xa4\x02\n\x1c\x43omputeGlobalNetworkEndpoint\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12%\n\x1dglobal_network_endpoint_group\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x12\n\nip_address\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x01\x12\x0f\n\x07project\x18\x06 \x01(\t\x12W\n\x08timeouts\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_global.ComputeGlobalNetworkEndpointXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n*ComputeGlobalNetworkEndpointGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xc2\x02\n!ComputeGlobalNetworkEndpointGroup\x12\x14\n\x0c\x64\x65\x66\x61ult_port\x18\x01 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1d\n\x15network_endpoint_type\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12\\\n\x08timeouts\x18\x08 \x01(\x0b\x32J.oak9.tython.gcp.compute_global.ComputeGlobalNetworkEndpointGroupXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_global_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEGLOBALFORWARDINGRULE_LABELSENTRY._options = None
  _COMPUTEGLOBALFORWARDINGRULE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEGLOBALADDRESSXTIMEOUTS._serialized_start=85
  _COMPUTEGLOBALADDRESSXTIMEOUTS._serialized_end=148
  _COMPUTEGLOBALADDRESS._serialized_start=151
  _COMPUTEGLOBALADDRESS._serialized_end=538
  _COMPUTEGLOBALFORWARDINGRULEXMETADATAFILTERSXFILTERLABELS._serialized_start=540
  _COMPUTEGLOBALFORWARDINGRULEXMETADATAFILTERSXFILTERLABELS._serialized_end=627
  _COMPUTEGLOBALFORWARDINGRULEXMETADATAFILTERS._serialized_start=630
  _COMPUTEGLOBALFORWARDINGRULEXMETADATAFILTERS._serialized_end=819
  _COMPUTEGLOBALFORWARDINGRULEXTIMEOUTS._serialized_start=821
  _COMPUTEGLOBALFORWARDINGRULEXTIMEOUTS._serialized_end=907
  _COMPUTEGLOBALFORWARDINGRULE._serialized_start=910
  _COMPUTEGLOBALFORWARDINGRULE._serialized_end=1636
  _COMPUTEGLOBALFORWARDINGRULE_LABELSENTRY._serialized_start=1591
  _COMPUTEGLOBALFORWARDINGRULE_LABELSENTRY._serialized_end=1636
  _COMPUTEGLOBALNETWORKENDPOINTXTIMEOUTS._serialized_start=1638
  _COMPUTEGLOBALNETWORKENDPOINTXTIMEOUTS._serialized_end=1709
  _COMPUTEGLOBALNETWORKENDPOINT._serialized_start=1712
  _COMPUTEGLOBALNETWORKENDPOINT._serialized_end=2004
  _COMPUTEGLOBALNETWORKENDPOINTGROUPXTIMEOUTS._serialized_start=2006
  _COMPUTEGLOBALNETWORKENDPOINTGROUPXTIMEOUTS._serialized_end=2082
  _COMPUTEGLOBALNETWORKENDPOINTGROUP._serialized_start=2085
  _COMPUTEGLOBALNETWORKENDPOINTGROUP._serialized_end=2407
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_applicationgateways.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7azure/azure_microsoft_network_applicationgateways.proto\x12\x37oak9.tython.azure.microsoft_network_applicationgateways\x1a\x13shared/shared.proto\"\x93\x01\n%Microsoft_Network_applicationGateways\x12j\n\x14\x61pplication_gateways\x18\x01 \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGateways\"\x1a\n\x0cHttpListener\x12\n\n\x02id\x18\x01 \x01(\t\"!\n\x13\x42\x61\x63kendHttpSettings\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x12\x42\x61\x63kendAddressPool\x12\n\n\x02id\x18\x01 \x01(\t\"\x1a\n\x0c\x46rontendPort\x12\n\n\x02id\x18\x01 \x01(\t\"%\n\x17\x46rontendIPConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\"\x14\n\x06Subnet\x12\n\n\x02id\x18\x01 \x01(\t\"\x1d\n\x0fPublicIpAddress\x12\n\n\x02id\x18\x01 \x01(\t\"\x82\x02\n-ApplicationGatewaysPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x89\x01\n%private_link_service_connection_state\x18\x03 \x01(\x0b\x32Z.oak9.tython.azure.microsoft_network_applicationgateways.PrivateLinkServiceConnectionState\"b\n!PrivateLinkServiceConnectionState\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10\x61\x63tions_required\x18\x03 \x01(\t\"\xb6\x1a\n\x13\x41pplicationGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x64\n\x04tags\x18\x04 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGateways.TagsEntry\x12[\n\x03sku\x18\x05 \x01(\x0b\x32N.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySku\x12h\n\nssl_policy\x18\x06 \x01(\x0b\x32T.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySslPolicy\x12}\n\x19gateway_ip_configurations\x18\x07 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayIPConfiguration\x12\x89\x01\n\x1b\x61uthentication_certificates\x18\x08 \x03(\x0b\x32\x64.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayAuthenticationCertificate\x12\x84\x01\n\x19trusted_root_certificates\x18\t \x03(\x0b\x32\x61.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayTrustedRootCertificate\x12\x88\x01\n\x1btrusted_client_certificates\x18\n \x03(\x0b\x32\x63.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayTrustedClientCertificate\x12s\n\x10ssl_certificates\x18\x0b \x03(\x0b\x32Y.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySslCertificate\x12\x86\x01\n\x1a\x66rontend_ip_configurations\x18\x0c \x03(\x0b\x32\x62.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayFrontendIPConfiguration\x12o\n\x0e\x66rontend_ports\x18\r \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayFrontendPort\x12`\n\x06probes\x18\x0e \x03(\x0b\x32P.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayProbe\x12|\n\x15\x62\x61\x63kend_address_pools\x18\x0f \x03(\x0b\x32].oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayBackendAddressPool\x12\x88\x01\n backend_http_settings_collection\x18\x10 \x03(\x0b\x32^.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayBackendHttpSettings\x12o\n\x0ehttp_listeners\x18\x11 \x03(\x0b\x32W.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayHttpListener\x12k\n\x0cssl_profiles\x18\x12 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySslProfile\x12l\n\rurl_path_maps\x18\x13 \x03(\x0b\x32U.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayUrlPathMap\x12|\n\x15request_routing_rules\x18\x14 \x03(\x0b\x32].oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRequestRoutingRule\x12t\n\x11rewrite_rule_sets\x18\x15 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRewriteRuleSet\x12\x81\x01\n\x17redirect_configurations\x18\x16 \x03(\x0b\x32`.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRedirectConfiguration\x12\x9e\x01\n&web_application_firewall_configuration\x18\x17 \x01(\x0b\x32n.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayWebApplicationFirewallConfiguration\x12\x17\n\x0f\x66irewall_policy\x18\x18 \x01(\t\x12\x14\n\x0c\x65nable_http2\x18\x19 \x01(\x08\x12\x13\n\x0b\x65nable_fips\x18\x1a \x01(\x08\x12\x82\x01\n\x17\x61utoscale_configuration\x18\x1b \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayAutoscaleConfiguration\x12\x88\x01\n\x1bprivate_link_configurations\x18\x1c \x03(\x0b\x32\x63.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayPrivateLinkConfiguration\x12{\n\x1b\x63ustom_error_configurations\x18\x1d \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayCustomError\x12)\n!force_firewall_policy_association\x18\x1e \x01(\x08\x12\r\n\x05zones\x18\x1f \x03(\t\x12\x61\n\x08identity\x18  \x01(\x0b\x32O.oak9.tython.azure.microsoft_network_applicationgateways.ManagedServiceIdentity\x12\xa1\x01\n1application_gateways_private_endpoint_connections\x18! \x03(\x0b\x32\x66.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaysPrivateEndpointConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x8d\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32k.oak9.tython.azure.microsoft_network_applicationgateways.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbd\x01\n*ApplicationGatewayPrivateLinkConfiguration\x12\x80\x01\n\x11ip_configurations\x18\x01 \x03(\x0b\x32\x65.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayPrivateLinkIpConfiguration\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xe0\x01\n,ApplicationGatewayPrivateLinkIpConfiguration\x12\x1a\n\x12private_ip_address\x18\x01 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x02 \x01(\t\x12O\n\x06subnet\x18\x03 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_applicationgateways.Subnet\x12\x0f\n\x07primary\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\"V\n(ApplicationGatewayAutoscaleConfiguration\x12\x14\n\x0cmin_capacity\x18\x01 \x01(\x05\x12\x14\n\x0cmax_capacity\x18\x02 \x01(\x05\"\x88\x04\n5ApplicationGatewayWebApplicationFirewallConfiguration\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x15\n\rfirewall_mode\x18\x02 \x01(\t\x12\x15\n\rrule_set_type\x18\x03 \x01(\t\x12\x18\n\x10rule_set_version\x18\x04 \x01(\t\x12\x82\x01\n\x14\x64isabled_rule_groups\x18\x05 \x03(\x0b\x32\x64.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayFirewallDisabledRuleGroup\x12\x1a\n\x12request_body_check\x18\x06 \x01(\x08\x12\x1d\n\x15max_request_body_size\x18\x07 \x01(\x05\x12#\n\x1bmax_request_body_size_in_kb\x18\x08 \x01(\x05\x12\x1f\n\x17\x66ile_upload_limit_in_mb\x18\t \x01(\x05\x12p\n\nexclusions\x18\n \x03(\x0b\x32\\.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayFirewallExclusion\"p\n#ApplicationGatewayFirewallExclusion\x12\x16\n\x0ematch_variable\x18\x01 \x01(\t\x12\x1f\n\x17selector_match_operator\x18\x02 \x01(\t\x12\x10\n\x08selector\x18\x03 \x01(\t\"U\n+ApplicationGatewayFirewallDisabledRuleGroup\x12\x17\n\x0frule_group_name\x18\x01 \x01(\t\x12\r\n\x05rules\x18\x02 \x03(\x05\"\xf9\x01\n\'ApplicationGatewayRedirectConfiguration\x12\x15\n\rredirect_type\x18\x01 \x01(\t\x12\x17\n\x0ftarget_listener\x18\x02 \x01(\t\x12\x12\n\ntarget_url\x18\x03 \x01(\t\x12\x14\n\x0cinclude_path\x18\x04 \x01(\x08\x12\x1c\n\x14include_query_string\x18\x05 \x01(\x08\x12\x1d\n\x15request_routing_rules\x18\x06 \x03(\t\x12\x15\n\rurl_path_maps\x18\x07 \x03(\t\x12\x12\n\npath_rules\x18\x08 \x03(\t\x12\x0c\n\x04name\x18\t \x01(\t\"\x9f\x01\n ApplicationGatewayRewriteRuleSet\x12m\n\rrewrite_rules\x18\x01 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRewriteRule\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xae\x02\n\x1d\x41pplicationGatewayRewriteRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rrule_sequence\x18\x02 \x01(\x05\x12s\n\nconditions\x18\x03 \x03(\x0b\x32_.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRewriteRuleCondition\x12s\n\naction_set\x18\x04 \x01(\x0b\x32_.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayRewriteRuleActionSet\"\xb1\x03\n&ApplicationGatewayRewriteRuleActionSet\x12\x85\x01\n\x1drequest_header_configurations\x18\x01 \x03(\x0b\x32^.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayHeaderConfiguration\x12\x86\x01\n\x1eresponse_header_configurations\x18\x02 \x03(\x0b\x32^.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayHeaderConfiguration\x12v\n\x11url_configuration\x18\x03 \x01(\x0b\x32[.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayUrlConfiguration\"k\n\"ApplicationGatewayUrlConfiguration\x12\x15\n\rmodified_path\x18\x01 \x01(\t\x12\x1d\n\x15modified_query_string\x18\x02 \x01(\t\x12\x0f\n\x07reroute\x18\x03 \x01(\x08\"R\n%ApplicationGatewayHeaderConfiguration\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\"p\n&ApplicationGatewayRewriteRuleCondition\x12\x10\n\x08variable\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x13\n\x0bignore_case\x18\x03 \x01(\x08\x12\x0e\n\x06negate\x18\x04 \x01(\x08\"\xdf\x03\n$ApplicationGatewayRequestRoutingRule\x12\x11\n\trule_type\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12i\n\x14\x62\x61\x63kend_address_pool\x18\x03 \x01(\x0b\x32K.oak9.tython.azure.microsoft_network_applicationgateways.BackendAddressPool\x12k\n\x15\x62\x61\x63kend_http_settings\x18\x04 \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_applicationgateways.BackendHttpSettings\x12\\\n\rhttp_listener\x18\x05 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network_applicationgateways.HttpListener\x12\x14\n\x0curl_path_map\x18\x06 \x01(\t\x12\x18\n\x10rewrite_rule_set\x18\x07 \x01(\t\x12\x1e\n\x16redirect_configuration\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\"\xac\x02\n\x1c\x41pplicationGatewayUrlPathMap\x12$\n\x1c\x64\x65\x66\x61ult_backend_address_pool\x18\x01 \x01(\t\x12%\n\x1d\x64\x65\x66\x61ult_backend_http_settings\x18\x02 \x01(\t\x12 \n\x18\x64\x65\x66\x61ult_rewrite_rule_set\x18\x03 \x01(\t\x12&\n\x1e\x64\x65\x66\x61ult_redirect_configuration\x18\x04 \x01(\t\x12g\n\npath_rules\x18\x05 \x03(\x0b\x32S.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayPathRule\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xe4\x02\n\x1a\x41pplicationGatewayPathRule\x12\r\n\x05paths\x18\x01 \x03(\t\x12i\n\x14\x62\x61\x63kend_address_pool\x18\x02 \x01(\x0b\x32K.oak9.tython.azure.microsoft_network_applicationgateways.BackendAddressPool\x12k\n\x15\x62\x61\x63kend_http_settings\x18\x03 \x01(\x0b\x32L.oak9.tython.azure.microsoft_network_applicationgateways.BackendHttpSettings\x12\x1e\n\x16redirect_configuration\x18\x04 \x01(\t\x12\x18\n\x10rewrite_rule_set\x18\x05 \x01(\t\x12\x17\n\x0f\x66irewall_policy\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\"\xc3\x02\n\x1c\x41pplicationGatewaySslProfile\x12#\n\x1btrusted_client_certificates\x18\x01 \x03(\t\x12h\n\nssl_policy\x18\x02 \x01(\x0b\x32T.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewaySslPolicy\x12\x85\x01\n\x19\x63lient_auth_configuration\x18\x03 \x01(\x0b\x32\x62.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayClientAuthConfiguration\x12\x0c\n\x04name\x18\x04 \x01(\t\"R\n)ApplicationGatewayClientAuthConfiguration\x12%\n\x1dverify_client_cert_issuer_d_n\x18\x01 \x01(\x08\"\xa6\x04\n\x1e\x41pplicationGatewayHttpListener\x12s\n\x19\x66rontend_ip_configuration\x18\x01 \x01(\x0b\x32P.oak9.tython.azure.microsoft_network_applicationgateways.FrontendIPConfiguration\x12\\\n\rfrontend_port\x18\x02 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network_applicationgateways.FrontendPort\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x17\n\x0fssl_certificate\x18\x05 \x01(\t\x12\x13\n\x0bssl_profile\x18\x06 \x01(\t\x12&\n\x1erequire_server_name_indication\x18\x07 \x01(\x08\x12{\n\x1b\x63ustom_error_configurations\x18\x08 \x03(\x0b\x32V.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayCustomError\x12\x17\n\x0f\x66irewall_policy\x18\t \x01(\t\x12\x12\n\nhost_names\x18\n \x03(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\"S\n\x1d\x41pplicationGatewayCustomError\x12\x13\n\x0bstatus_code\x18\x01 \x01(\t\x12\x1d\n\x15\x63ustom_error_page_url\x18\x02 \x01(\t\"\xe3\x03\n%ApplicationGatewayBackendHttpSettings\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x1d\n\x15\x63ookie_based_affinity\x18\x03 \x01(\t\x12\x17\n\x0frequest_timeout\x18\x04 \x01(\x05\x12\r\n\x05probe\x18\x05 \x01(\t\x12#\n\x1b\x61uthentication_certificates\x18\x06 \x03(\t\x12!\n\x19trusted_root_certificates\x18\x07 \x03(\t\x12z\n\x13\x63onnection_draining\x18\x08 \x01(\x0b\x32].oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayConnectionDraining\x12\x11\n\thost_name\x18\t \x01(\t\x12+\n#pick_host_name_from_backend_address\x18\n \x01(\x08\x12\x1c\n\x14\x61\x66\x66inity_cookie_name\x18\x0b \x01(\t\x12\x15\n\rprobe_enabled\x18\x0c \x01(\x08\x12\x0c\n\x04path\x18\r \x01(\t\x12\x0c\n\x04name\x18\x0e \x01(\t\"U\n$ApplicationGatewayConnectionDraining\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1c\n\x14\x64rain_timeout_in_sec\x18\x02 \x01(\x05\"\xaa\x01\n$ApplicationGatewayBackendAddressPool\x12t\n\x11\x62\x61\x63kend_addresses\x18\x01 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayBackendAddress\x12\x0c\n\x04name\x18\x02 \x01(\t\"D\n ApplicationGatewayBackendAddress\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\"\xdf\x02\n\x17\x41pplicationGatewayProbe\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x10\n\x08interval\x18\x04 \x01(\x05\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x1b\n\x13unhealthy_threshold\x18\x06 \x01(\x05\x12\x31\n)pick_host_name_from_backend_http_settings\x18\x07 \x01(\x08\x12\x13\n\x0bmin_servers\x18\x08 \x01(\x05\x12r\n\x05match\x18\t \x01(\x0b\x32\x63.oak9.tython.azure.microsoft_network_applicationgateways.ApplicationGatewayProbeHealthResponseMatch\x12\x0c\n\x04port\x18\n \x01(\x05\x12\x0c\n\x04name\x18\x0b \x01(\t\"P\n*ApplicationGatewayProbeHealthResponseMatch\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12\x14\n\x0cstatus_codes\x18\x02 \x03(\t\"<\n\x1e\x41pplicationGatewayFrontendPort\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd5\x02\n)ApplicationGatewayFrontendIPConfiguration\x12\x1a\n\x12private_ip_address\x18\x01 \x01(\t\x12$\n\x1cprivate_ip_allocation_method\x18\x02 \x01(\t\x12O\n\x06subnet\x18\x03 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_applicationgateways.Subnet\x12\"\n\x1aprivate_link_configuration\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x63\n\x11public_ip_address\x18\x06 \x01(\x0b\x32H.oak9.tython.azure.microsoft_network_applicationgateways.PublicIpAddress\"m\n ApplicationGatewaySslCertificate\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x1b\n\x13key_vault_secret_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"H\n*ApplicationGatewayTrustedClientCertificate\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n(ApplicationGatewayTrustedRootCertificate\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x1b\n\x13key_vault_secret_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"I\n+ApplicationGatewayAuthenticationCertificate\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x82\x01\n!ApplicationGatewayIPConfiguration\x12O\n\x06subnet\x18\x01 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_applicationgateways.Subnet\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9c\x01\n\x1b\x41pplicationGatewaySslPolicy\x12\x1e\n\x16\x64isabled_ssl_protocols\x18\x01 \x03(\t\x12\x13\n\x0bpolicy_type\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_name\x18\x03 \x01(\t\x12\x15\n\rcipher_suites\x18\x04 \x03(\t\x12\x1c\n\x14min_protocol_version\x18\x05 \x01(\t\"E\n\x15\x41pplicationGatewaySku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61pacity\x18\x03 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_applicationgateways_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATIONGATEWAYS_TAGSENTRY._options = None
  _APPLICATIONGATEWAYS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_APPLICATIONGATEWAYS._serialized_start=138
  _MICROSOFT_NETWORK_APPLICATIONGATEWAYS._serialized_end=285
  _HTTPLISTENER._serialized_start=287
  _HTTPLISTENER._serialized_end=313
  _BACKENDHTTPSETTINGS._serialized_start=315
  _BACKENDHTTPSETTINGS._serialized_end=348
  _BACKENDADDRESSPOOL._serialized_start=350
  _BACKENDADDRESSPOOL._serialized_end=382
  _FRONTENDPORT._serialized_start=384
  _FRONTENDPORT._serialized_end=410
  _FRONTENDIPCONFIGURATION._serialized_start=412
  _FRONTENDIPCONFIGURATION._serialized_end=449
  _SUBNET._serialized_start=451
  _SUBNET._serialized_end=471
  _PUBLICIPADDRESS._serialized_start=473
  _PUBLICIPADDRESS._serialized_end=502
  _APPLICATIONGATEWAYSPRIVATEENDPOINTCONNECTIONS._serialized_start=505
  _APPLICATIONGATEWAYSPRIVATEENDPOINTCONNECTIONS._serialized_end=763
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=765
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=863
  _APPLICATIONGATEWAYS._serialized_start=866
  _APPLICATIONGATEWAYS._serialized_end=4248
  _APPLICATIONGATEWAYS_TAGSENTRY._serialized_start=4205
  _APPLICATIONGATEWAYS_TAGSENTRY._serialized_end=4248
  _MANAGEDSERVICEIDENTITY._serialized_start=4251
  _MANAGEDSERVICEIDENTITY._serialized_end=4496
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=4435
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=4496
  _APPLICATIONGATEWAYPRIVATELINKCONFIGURATION._serialized_start=4499
  _APPLICATIONGATEWAYPRIVATELINKCONFIGURATION._serialized_end=4688
  _APPLICATIONGATEWAYPRIVATELINKIPCONFIGURATION._serialized_start=4691
  _APPLICATIONGATEWAYPRIVATELINKIPCONFIGURATION._serialized_end=4915
  _APPLICATIONGATEWAYAUTOSCALECONFIGURATION._serialized_start=4917
  _APPLICATIONGATEWAYAUTOSCALECONFIGURATION._serialized_end=5003
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLCONFIGURATION._serialized_start=5006
  _APPLICATIONGATEWAYWEBAPPLICATIONFIREWALLCONFIGURATION._serialized_end=5526
  _APPLICATIONGATEWAYFIREWALLEXCLUSION._serialized_start=5528
  _APPLICATIONGATEWAYFIREWALLEXCLUSION._serialized_end=5640
  _APPLICATIONGATEWAYFIREWALLDISABLEDRULEGROUP._serialized_start=5642
  _APPLICATIONGATEWAYFIREWALLDISABLEDRULEGROUP._serialized_end=5727
  _APPLICATIONGATEWAYREDIRECTCONFIGURATION._serialized_start=5730
  _APPLICATIONGATEWAYREDIRECTCONFIGURATION._serialized_end=5979
  _APPLICATIONGATEWAYREWRITERULESET._serialized_start=5982
  _APPLICATIONGATEWAYREWRITERULESET._serialized_end=6141
  _APPLICATIONGATEWAYREWRITERULE._serialized_start=6144
  _APPLICATIONGATEWAYREWRITERULE._serialized_end=6446
  _APPLICATIONGATEWAYREWRITERULEACTIONSET._serialized_start=6449
  _APPLICATIONGATEWAYREWRITERULEACTIONSET._serialized_end=6882
  _APPLICATIONGATEWAYURLCONFIGURATION._serialized_start=6884
  _APPLICATIONGATEWAYURLCONFIGURATION._serialized_end=6991
  _APPLICATIONGATEWAYHEADERCONFIGURATION._serialized_start=6993
  _APPLICATIONGATEWAYHEADERCONFIGURATION._serialized_end=7075
  _APPLICATIONGATEWAYREWRITERULECONDITION._serialized_start=7077
  _APPLICATIONGATEWAYREWRITERULECONDITION._serialized_end=7189
  _APPLICATIONGATEWAYREQUESTROUTINGRULE._serialized_start=7192
  _APPLICATIONGATEWAYREQUESTROUTINGRULE._serialized_end=7671
  _APPLICATIONGATEWAYURLPATHMAP._serialized_start=7674
  _APPLICATIONGATEWAYURLPATHMAP._serialized_end=7974
  _APPLICATIONGATEWAYPATHRULE._serialized_start=7977
  _APPLICATIONGATEWAYPATHRULE._serialized_end=8333
  _APPLICATIONGATEWAYSSLPROFILE._serialized_start=8336
  _APPLICATIONGATEWAYSSLPROFILE._serialized_end=8659
  _APPLICATIONGATEWAYCLIENTAUTHCONFIGURATION._serialized_start=8661
  _APPLICATIONGATEWAYCLIENTAUTHCONFIGURATION._serialized_end=8743
  _APPLICATIONGATEWAYHTTPLISTENER._serialized_start=8746
  _APPLICATIONGATEWAYHTTPLISTENER._serialized_end=9296
  _APPLICATIONGATEWAYCUSTOMERROR._serialized_start=9298
  _APPLICATIONGATEWAYCUSTOMERROR._serialized_end=9381
  _APPLICATIONGATEWAYBACKENDHTTPSETTINGS._serialized_start=9384
  _APPLICATIONGATEWAYBACKENDHTTPSETTINGS._serialized_end=9867
  _APPLICATIONGATEWAYCONNECTIONDRAINING._serialized_start=9869
  _APPLICATIONGATEWAYCONNECTIONDRAINING._serialized_end=9954
  _APPLICATIONGATEWAYBACKENDADDRESSPOOL._serialized_start=9957
  _APPLICATIONGATEWAYBACKENDADDRESSPOOL._serialized_end=10127
  _APPLICATIONGATEWAYBACKENDADDRESS._serialized_start=10129
  _APPLICATIONGATEWAYBACKENDADDRESS._serialized_end=10197
  _APPLICATIONGATEWAYPROBE._serialized_start=10200
  _APPLICATIONGATEWAYPROBE._serialized_end=10551
  _APPLICATIONGATEWAYPROBEHEALTHRESPONSEMATCH._serialized_start=10553
  _APPLICATIONGATEWAYPROBEHEALTHRESPONSEMATCH._serialized_end=10633
  _APPLICATIONGATEWAYFRONTENDPORT._serialized_start=10635
  _APPLICATIONGATEWAYFRONTENDPORT._serialized_end=10695
  _APPLICATIONGATEWAYFRONTENDIPCONFIGURATION._serialized_start=10698
  _APPLICATIONGATEWAYFRONTENDIPCONFIGURATION._serialized_end=11039
  _APPLICATIONGATEWAYSSLCERTIFICATE._serialized_start=11041
  _APPLICATIONGATEWAYSSLCERTIFICATE._serialized_end=11150
  _APPLICATIONGATEWAYTRUSTEDCLIENTCERTIFICATE._serialized_start=11152
  _APPLICATIONGATEWAYTRUSTEDCLIENTCERTIFICATE._serialized_end=11224
  _APPLICATIONGATEWAYTRUSTEDROOTCERTIFICATE._serialized_start=11226
  _APPLICATIONGATEWAYTRUSTEDROOTCERTIFICATE._serialized_end=11325
  _APPLICATIONGATEWAYAUTHENTICATIONCERTIFICATE._serialized_start=11327
  _APPLICATIONGATEWAYAUTHENTICATIONCERTIFICATE._serialized_end=11400
  _APPLICATIONGATEWAYIPCONFIGURATION._serialized_start=11403
  _APPLICATIONGATEWAYIPCONFIGURATION._serialized_end=11533
  _APPLICATIONGATEWAYSSLPOLICY._serialized_start=11536
  _APPLICATIONGATEWAYSSLPOLICY._serialized_end=11692
  _APPLICATIONGATEWAYSKU._serialized_start=11694
  _APPLICATIONGATEWAYSKU._serialized_end=11763
# @@protoc_insertion_point(module_scope)
